@@ -121,21 +121,24 @@ def create_user():
                 data = request.get_json()
                 LOGS.logger.info(data)
                 condition = (
-                    'name' in data and
-                    'email' in data and
-                    'department' in data and
+                    'sn' in data and
+                    'mail' in data and
+                    'ou' in data and
                     'registration_number' in data and
                     'role' in data
                     )
                 if not condition:
                     return bad_request(service_code=SERVICE_CODE)
                 else:
+                    manager = data.get('manager', False)
                     User.create(
-                        data['name'],
-                        data['email'],
-                        data['department'],
+                        data['sn'],
+                        data['mail'],
+                        data['ou'],
                         data['registration_number'],
-                        data['role']
+                        data['role'],
+                        data['mobile'],
+                        manager
                         )
                     return created(service_code=SERVICE_CODE)
             else:
