@@ -24,6 +24,16 @@ __all__ = [
     ]
 
 
+def ldap_conn(command, *args, **kwargs):
+    conn = consts.LDAP_CONN
+    conn.bind(
+        consts.LDAP_ADMIN_DN,
+        consts.CONFIG['LDAP']['LDAP_ADMIN_PASSWORD']
+        )
+    result = getattr(conn, command)(*args, **kwargs)
+    return result
+
+
 class Email(object):
     """Notifications"""
 
@@ -91,7 +101,6 @@ class LdapInspector(object):
     """Encapsulation des méthodes de base pour gérer un type d'objet"""
 
     def __init__(self, objectType):
-        self.connection = consts.LDAP_CONN
         if objectType not in consts.CONFIG:
             raise ValueError(
                 "'{objectType}' n'existe pas dans la configuration".format(
@@ -111,7 +120,7 @@ class LdapInspector(object):
 
     def read(self, dn):
         """Lecture des informations sous un domaine précis"""
-        result = consts.LDAP_CONN.read_s(dn, attrlist=self.attributes)
+        result = ldap_conn('read_s', dn, attrlist=self.attributes)
         bar = {}
         for key, value in result.items():
             _value = []
@@ -149,7 +158,8 @@ class LdapInspector(object):
                     identifier=self.identifier,
                     parameter=parameter
                     )
-        data = consts.LDAP_CONN.search_s(
+        data = ldap_conn(
+            'search_s',
             self.top_domain,
             ldap.SCOPE_SUBTREE,
             filterstr=filterstr,
@@ -237,6 +247,6 @@ class LdapObject(object):
         action = ldap.MOD_REPLACE
         if add:
             action = ldap.MOD_ADD
-        consts.LDAP_CONN.modify_s(self.dn, [(action, key, value)])
+        ldap_conn('modify_s', self.dn, [(action, key, value)])
 
 # EOF
